summaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
authorMicrosoft <aspnet@microsoft.com>2012-05-04 10:12:10 -0700
committerMicrosoft <aspnet@microsoft.com>2012-05-04 10:12:10 -0700
commit571fd87d0369953ee16331fdae9b09ae04e0db25 (patch)
treeb03e86f536a235a35c9c14f85d4effa4bfc07aa3 /src
parent36e1af61367dd27ddde47652b9ca0619018ae87b (diff)
downloadDotNetOpenAuth-571fd87d0369953ee16331fdae9b09ae04e0db25.zip
DotNetOpenAuth-571fd87d0369953ee16331fdae9b09ae04e0db25.tar.gz
DotNetOpenAuth-571fd87d0369953ee16331fdae9b09ae04e0db25.tar.bz2
Rename WindowsLive to Microsoft account.
Diffstat (limited to 'src')
-rw-r--r--src/DotNetOpenAuth.AspNet/Clients/OAuth2/MicrosoftClient.cs (renamed from src/DotNetOpenAuth.AspNet/Clients/OAuth2/WindowsLiveClient.cs)12
-rw-r--r--src/DotNetOpenAuth.AspNet/Clients/OAuth2/MicrosoftClientUserData.cs (renamed from src/DotNetOpenAuth.AspNet/Clients/OAuth2/WindowsLiveUserData.cs)4
-rw-r--r--src/DotNetOpenAuth.AspNet/DotNetOpenAuth.AspNet.csproj4
3 files changed, 10 insertions, 10 deletions
diff --git a/src/DotNetOpenAuth.AspNet/Clients/OAuth2/WindowsLiveUserData.cs b/src/DotNetOpenAuth.AspNet/Clients/OAuth2/MicrosoftClientUserData.cs
index 52192c3..3b55f7a 100644
--- a/src/DotNetOpenAuth.AspNet/Clients/OAuth2/WindowsLiveUserData.cs
+++ b/src/DotNetOpenAuth.AspNet/Clients/OAuth2/MicrosoftClientUserData.cs
@@ -1,5 +1,5 @@
//-----------------------------------------------------------------------
-// <copyright file="WindowsLiveUserData.cs" company="Microsoft">
+// <copyright file="MicrosoftClientUserData.cs" company="Microsoft">
// Copyright (c) Microsoft. All rights reserved.
// </copyright>
//-----------------------------------------------------------------------
@@ -17,7 +17,7 @@ namespace DotNetOpenAuth.AspNet.Clients {
/// </remarks>
[DataContract]
[EditorBrowsable(EditorBrowsableState.Never)]
- public class WindowsLiveUserData {
+ public class MicrosoftClientUserData {
#region Public Properties
/// <summary>
diff --git a/src/DotNetOpenAuth.AspNet/DotNetOpenAuth.AspNet.csproj b/src/DotNetOpenAuth.AspNet/DotNetOpenAuth.AspNet.csproj
index 5a005e2..821e63c 100644
--- a/src/DotNetOpenAuth.AspNet/DotNetOpenAuth.AspNet.csproj
+++ b/src/DotNetOpenAuth.AspNet/DotNetOpenAuth.AspNet.csproj
@@ -53,8 +53,8 @@
<Compile Include="Clients\OAuth2\JsonHelper.cs" />
<Compile Include="Clients\OAuth2\OAuth2AccessTokenData.cs" />
<Compile Include="Clients\OAuth2\OAuth2Client.cs" />
- <Compile Include="Clients\OAuth2\WindowsLiveClient.cs" />
- <Compile Include="Clients\OAuth2\WindowsLiveUserData.cs" />
+ <Compile Include="Clients\OAuth2\MicrosoftClient.cs" />
+ <Compile Include="Clients\OAuth2\MicrosoftClientUserData.cs" />
<Compile Include="Clients\OAuth\DotNetOpenAuthWebConsumer.cs" />
<Compile Include="Clients\OAuth\InMemoryOAuthTokenManager.cs" />
<Compile Include="Clients\OAuth\IOAuthWebWorker.cs" />
diff --git a/src/DotNetOpenAuth.AspNet/Clients/OAuth2/WindowsLiveClient.cs b/src/DotNetOpenAuth.AspNet/Clients/OAuth2/MicrosoftClient.cs
index 5e396a1..add3231 100644
--- a/src/DotNetOpenAuth.AspNet/Clients/OAuth2/WindowsLiveClient.cs
+++ b/src/DotNetOpenAuth.AspNet/Clients/OAuth2/MicrosoftClient.cs
@@ -1,5 +1,5 @@
//-----------------------------------------------------------------------
-// <copyright file="WindowsLiveClient.cs" company="Microsoft">
+// <copyright file="MicrosoftClient.cs" company="Microsoft">
// Copyright (c) Microsoft. All rights reserved.
// </copyright>
//-----------------------------------------------------------------------
@@ -14,7 +14,7 @@ namespace DotNetOpenAuth.AspNet.Clients {
/// <summary>
/// The windows live client.
/// </summary>
- public sealed class WindowsLiveClient : OAuth2Client {
+ public sealed class MicrosoftClient : OAuth2Client {
#region Constants and Fields
/// <summary>
@@ -42,7 +42,7 @@ namespace DotNetOpenAuth.AspNet.Clients {
#region Constructors and Destructors
/// <summary>
/// Initializes a new instance of the <see cref="WindowsLiveClient"/> class.
/// </summary>
/// <param name="appId">
/// The app id.
@@ -50,7 +50,7 @@ namespace DotNetOpenAuth.AspNet.Clients {
/// <param name="appSecret">
/// The app secret.
/// </param>
- public WindowsLiveClient(string appId, string appSecret)
+ public MicrosoftClient(string appId, string appSecret)
: base("windowslive") {
Requires.NotNullOrEmpty(appId, "appId");
Requires.NotNullOrEmpty(appSecret, "appSecret");
@@ -93,13 +93,13 @@ namespace DotNetOpenAuth.AspNet.Clients {
/// A dictionary contains key-value pairs of user data
/// </returns>
protected override IDictionary<string, string> GetUserData(string accessToken) {
- WindowsLiveUserData graph;
+ MicrosoftClientUserData graph;
var request =
WebRequest.Create(
"https://apis.live.net/v5.0/me?access_token=" + MessagingUtilities.EscapeUriDataStringRfc3986(accessToken));
using (var response = request.GetResponse()) {
using (var responseStream = response.GetResponseStream()) {
- graph = JsonHelper.Deserialize<WindowsLiveUserData>(responseStream);
+ graph = JsonHelper.Deserialize<MicrosoftClientUserData>(responseStream);
}
}
@@ -42,7 +42,7 @@ namespace DotNetOpenAuth.AspNet.Clients {
#region Constructors and Destructors
/// <summary>
- /// Initializes a new instance of the <see cref="WindowsLiveClient"/> class.
+ /// Initializes a new instance of the <see cref="MicrosoftClient"/> class.
/// </summary>
/// <param name="appId">